import React, { DetailedHTMLProps, HTMLAttributes } from "react";
import { QueueChangeEventHandler } from "./queue.js";
export type SpanProps = DetailedHTMLProps<HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>;
export type SpeechSynthesisErrorHandler = (error: Error) => any;
export type SpeechSynthesisEventHandler = (event: SpeechSynthesisEvent) => any;
export type useSpeechProps = {
    text: string | JSX.Element;
    pitch?: number;
    rate?: number;
    volume?: number;
    lang?: string;
    voiceURI?: string | string[];
    highlightText?: boolean;
    highlightProps?: SpanProps;
    preserveUtteranceQueue?: boolean;
    onError?: SpeechSynthesisErrorHandler;
    onStart?: SpeechSynthesisEventHandler;
    onResume?: SpeechSynthesisEventHandler;
    onPause?: SpeechSynthesisEventHandler;
    onStop?: SpeechSynthesisEventHandler;
    onBoundary?: SpeechSynthesisEventHandler;
    onQueueChange?: QueueChangeEventHandler;
};
export type SpeechStatus = "started" | "paused" | "stopped" | "queued";
export declare function useSpeech({ text, pitch, rate, volume, lang, voiceURI, highlightText, highlightProps, preserveUtteranceQueue, onError, onStart, onResume, onPause, onStop, onBoundary, onQueueChange, }: useSpeechProps): {
    Text: () => React.ReactNode;
    speechStatus: SpeechStatus;
    isInQueue: boolean;
    start: () => any;
    pause: () => void;
    stop: () => void;
};
